@@ -11,9 +11,9 @@
 #' risk aversion parameter (obtained as output of the function [CEriskav()]).
 #' @template args-pos
 #' @param graph A string used to select the graphical engine to use for
-#' plotting. Should (partial-)match the two options `"base"` or
-#' `"ggplot2"`. Default value is `"base"`.
-#' @param ...  Arguments to be passed to methods, such as graphical parameters
+#' plotting. Should (partial-)match the options `"base"`,
+#' `"ggplot2"` or `"plotly"`. Default value is `"base"`.
+#' @param ... Arguments to be passed to methods, such as graphical parameters
 #' (see [par()]).
 #' 
 #' @return \item{list(eib,evi)}{A two-elements named list of the ggplot objects
@@ -43,10 +43,10 @@
 #' 
 #' # See Baio G., Dawid A.P. (2011) for a detailed description of the 
 #' # Bayesian model and economic problem
-#' #
+#' 
 #' # Load the processed results of the MCMC simulation model
 #' data(Vaccine)
-#' # 
+#' 
 #' # Runs the health economic evaluation using BCEA
 #' m <- bcea(e=eff, c=cost,    # defines the variables of 
 #'                             #  effectiveness and cost
@@ -59,15 +59,15 @@
 #'                             #  in a grid from the interval (0,Kmax)
 #'       plot=FALSE            # inhibits graphical output
 #' )
-#' #
-#' # Define the vector of values for the risk aversion parameter, r, eg:
+#' 
+#' # Define the vector of values for the risk aversion parameter, r, e.g.:
 #' r <- c(1e-10, 0.005, 0.020, 0.035) 
-#' #
+#' 
 #' # Run the cost-effectiveness analysis accounting for risk aversion
 #' \donttest{
 #'    CEriskav(m) <- r
 #' }
-#' #
+#' 
 #' # produce the plots
 #' \donttest{
 #'    plot(m)
@@ -80,8 +80,8 @@
 #' @export
 #' 
 plot.CEriskav <- function(x,
-                          pos = c(0, 1),
-                          graph = c("base", "ggplot2"),
+                          pos = "topright",
+                          graph = c("base", "ggplot2", "plotly"),
                           ...) {
   
   graph <- match.arg(graph)
@@ -90,12 +90,13 @@ plot.CEriskav <- function(x,
   # graph_params <- prep_CEriskav_params(...)
   
   if (is_baseplot(graph)) {
-    
-    CEriskav_plot_base(x, pos)
-    
-  } else {
-    
-    CEriskav_plot_ggplot(x, pos)
+    CEriskav_plot_base(x,
+                       pos_legend = pos)
+  } else if (is_ggplot(graph)) {
+    CEriskav_plot_ggplot(x,
+                         pos_legend = pos)
+  } else if (is_plotly(graph)) {
+    CEriskav_plot_plotly(x,
+                         pos_legend = pos)
   }
 }
-
