@@ -4,14 +4,14 @@
 # library(BCEA)
 
 
-load(test_path("smoking_ce.RData"))
+load(test_path("ce_smoking.RData"))
 
 test_that("errors for comparison groups base R", {
 
 he <- bcea(eff, cost, ref = 4, Kmax = 500)
   
-  expect_silent(eib.plot(he, comparison = 2))
-  expect_silent(eib.plot(he, comparison = c(2,3)))
+  # expect_silent(eib.plot(he, comparison = 2))
+  # expect_silent(eib.plot(he, comparison = c(2,3)))
   
   expect_error(eib.plot(he, comparison = 4),
                "Can't select Reference group. Change Reference first.")
